@@ -57,6 +57,8 @@ class Firewall(PanDevice):
     NAME = "serial"
     DEFAULT_VSYS = "vsys1"
     CHILDTYPES = (
+        "device.AuthenticationProfile",
+        "device.AuthenticationSequence",
         "device.Vsys",
         "device.VsysResources",
         "device.SystemSettings",
@@ -239,6 +241,7 @@ class Firewall(PanDevice):
 
         """
         super(Firewall, self)._save_system_info(system_info)
+        self.content_version = system_info["system"]["app-version"]
         self.multi_vsys = system_info["system"]["multi-vsys"] == "on"
 
     def element(self):
@@ -341,13 +344,10 @@ class Firewall(PanDevice):
             )
         op_vars = (
             Var("serial"),
-            Var("ip-address", "management_ip"),
-            Var("sw-version", "version"),
             Var("multi-vsys", vartype="bool"),
             Var("vsys_id", "vsys", default="vsys1"),
             Var("vsys_name"),
             Var("ha/state/peer/serial", "serial_ha_peer"),
-            Var("connected", "state.connected"),
         )
         if len(xml[0]) > 1:
             # This is a 'show devices' op command
@@ -360,11 +360,15 @@ class Firewall(PanDevice):
                 system = fw.find_or_create(None, device.SystemSettings)
                 system.hostname = entry.findtext("hostname")
                 system.ip_address = entry.findtext("ip-address")
+                if entry.findtext("ipv6-address") != "unknown":
+                    system.ipv6_address = entry.findtext("ipv6-address")
                 # Add state
                 fw.state.connected = yesno(entry.findtext("connected"))
                 fw.state.unsupported_version = yesno(
                     entry.findtext("unsupported-version")
                 )
+                fw._set_version_and_version_info(entry.findtext("sw-version"))
+                fw.content_version = entry.findtext("app-version")
         else:
             # This is a config command
             # For each vsys, instantiate a new firewall
@@ -386,7 +390,7 @@ class Firewall(PanDevice):
         result = self.xapi.xml_root()
         if self._version_info >= (9, 0, 0):
             regex = re.compile(
-                r"load average: ([\d\.]+).*? ([\d\.]+) id,.*KiB Mem : (\d+) total,.*? (\d+) free",
+                r"load average: ([\d\.]+).*? ([\d\.]+) id,.*KiB Mem :\s+(\d+) total,.*? (\d+) free",
                 re.DOTALL,
             )
         else:
@@ -505,7 +509,20 @@ class FirewallState(object):
 
 
 class FirewallCommit(object):
-    """Normalization of a firewall commit."""
+    """Normalization of a firewall commit.
+
+    Instances of this class can be passed in to ``Firewall.commit()`` (inherited from
+    :meth:`panos.base.PanDevice.commit()`) as the ``cmd`` parameter.
+
+    Args:
+        description (str): The commit message.
+        admins (list): (PAN-OS 8.0+) List of admins whose changes are to be committed.
+        exclude_device_and_network (bool): Set to True to exclude device and network changes.
+        exclude_shared_objects (bool): Set to True to exclude shared objects changes.
+        exclude_policy_and_objects (bool): Set to True to exclude policy and objects changes.
+        force (bool): Set to True to force a commit even if one is not needed.
+
+    """
 
     def __init__(
         self,
