@@ -81,6 +81,9 @@ class DeviceGroup(VersionedPanObject):
 
         self._params = tuple(params)
 
+    def _setup_opstate(self):
+        self.opstate = DeviceGroupOpState(self)
+
     @property
     def vsys(self):
         return self.name
@@ -91,6 +94,68 @@ class DeviceGroup(VersionedPanObject):
     def xpath_vsys(self):
         return self.xpath()
 
+    def _setup_opstate(self):
+        self.opstate = DeviceGroupOpState(self)
+
+
+class DeviceGroupOpState(object):
+    """Operational state handling for device group classes."""
+
+    def __init__(self, obj):
+        self.dg_hierarchy = DeviceGroupHierarchy(obj)
+
+
+class DeviceGroupHierarchy(object):
+    """Operational state handling for device group hierarchy.
+
+    Args:
+        parent (str): This device group's parent.
+
+    """
+
+    def __init__(self, obj):
+        self.obj = obj
+        self.parent = None
+
+    def refresh(self):
+        """Refresh the ``parent`` from the state."""
+
+        dev = self.obj.panorama()
+        state = dev.opstate.dg_hierarchy.fetch()
+        self.parent = state[self.obj.uid]
+
+    def update(self):
+        """Change this device group's hierarchical parent.
+
+        **Modifies the live device**
+
+        This operation results in a job being submitted to the backend, which
+        this function will block until the move is completed.  The return value of
+        this function is what is returned from
+        :meth:`panos.base.PanDevice.syncjob()`.
+
+        Returns:
+            dict: Job result
+
+        """
+        dev = self.obj.panorama()
+        logger.debug(
+            '{0}: update hierarchical parent for "{1}": {2}'.format(
+                dev.id, self.obj.uid, self.parent
+            )
+        )
+
+        e = ET.Element("request")
+        em = ET.SubElement(e, "move-dg")
+        eme = ET.SubElement(em, "entry", {"name": self.obj.name})
+
+        if self.parent is not None:
+            ET.SubElement(eme, "new-parent-dg").text = self.parent
+
+        cmd = ET.tostring(e, encoding="utf-8")
+        resp = dev.op(cmd, cmd_xml=False)
+        return dev.syncjob(resp)
+
 
 class Template(VersionedPanObject):
     """A panorama template.
@@ -751,9 +816,72 @@ class Panorama(base.PanDevice):
 
         return ans
 
+    def _setup_opstate(self):
+        self.opstate = PanoramaOpState(self)
+
+
+class PanoramaOpState(object):
+    """Panorama OP state handling."""
+
+    def __init__(self, obj):
+        self.dg_hierarchy = PanoramaDeviceGroupHierarchy(obj)
+
+
+class PanoramaDeviceGroupHierarchy(object):
+    """Operational state handling for device group hierarchy."""
+
+    def __init__(self, obj):
+        self.obj = obj
+        self.parent = None
+
+    def fetch(self):
+        """Returns a dict of device groups and their parents.
+
+        Keys in the dict are the device group's name, while the value is the
+        name of that device group's parent.  Top level device groups will have
+        a parent of ``None``.
+
+        Returns:
+            dict
+
+        """
+
+        resp = self.obj.op("show dg-hierarchy")
+        data = resp.find("./result/dg-hierarchy")
+
+        ans = {}
+        nodes = [(None, x) for x in data.findall("./dg")]
+        for parent, elm in iter(nodes):
+            ans[elm.attrib["name"]] = parent
+            nodes.extend((elm.attrib["name"], x) for x in elm.findall("./dg"))
+
+        return ans
+
 
 class PanoramaCommit(object):
-    """Normalization of a Panorama commit."""
+    """Normalization of a Panorama commit.
+
+    This performs a commit to Panorama.  Changes must first be committed to Panorama before
+    they can be pushed out elsewhere, such as to device groups or log collectors.
+
+    Instances of this class can be passed in to ``Panorama.commit()`` (inherited from
+    :meth:`panos.base.PanDevice.commit()`) as the ``cmd`` parameter.
+
+    Args:
+        description (str): The commit message.
+        admins (list): (PAN-OS 8.0+) List of admins whose changes are to be committed.
+        device_groups (list): List of device groups to save changes for.
+        templates (list): List of templates to save changes for.
+        template_stacks (list): List of template stacks to save changes for.
+        wildfire_appliances (list): List of Wildfire appliances to save changes for.
+        wildfire_clusters (list): List of Wildfire clusters to save changes for.
+        log_collectors (list): List of log collectors to save changes for.
+        log_collector_groups (list): List of log collector groups to save changes for.
+        exclude_device_and_network (bool): Set to True to exclude device and network changes.
+        exclude_shared_objects (bool): Set to True to exclude shared objects changes.
+        force (bool): Set to True to force a commit even if one is not needed.
+
+    """
 
     def __init__(
         self,
@@ -864,7 +992,32 @@ class PanoramaCommit(object):
 
 
 class PanoramaCommitAll(object):
-    """Normalization of a Panorama commit all."""
+    """Normalization of a Panorama commit all.
+
+    This performs a commit-all in Panorama, pushing config out to the specified
+    location.
+
+    Instances of this class can be passed in to ``Panorama.commit()`` (inherited from
+    :meth:`panos.base.PanDevice.commit()`) as the ``cmd`` parameter.
+
+    Args:
+        style (str): The type of commit-all to perform:
+                * device group
+                * template
+                * template stack
+                * log collector group
+                * wildfire appliance
+                * wildfire cluster
+        name (str): The name of the location to push the config to (e.g. - name
+            of the device group, name of the template, etc).
+        description (str): The commit message.
+        include_template (bool): (For `device group` style commits) Set to True to include
+            template changes.
+        force_template_values (bool): (For `device group`, `template`, or `template stack`
+            style commits) Set to True to force template values.
+        devices (list): (For `device group`, `template`, or `template stack` style
+            commits) Specific devices to commit to.
+    """
 
     STYLE_DEVICE_GROUP = "device group"
     STYLE_TEMPLATE = "template"
